@@ -201,7 +201,7 @@ class EnterpriseEnrollmentsViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
         return created_max['created__max']
 
     @action(detail=False)
-    def overview(self, request, **kwargs):  # pylint: disable=unused-argument
+    def overview(self, request, **kwargs):
         """
         Returns the following data:
             - # of enrolled learners;
@@ -311,7 +311,7 @@ class EnterpriseUsersViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
             )
         return queryset
 
-    def list(self, request, **kwargs):
+    def list(self, request, **kwargs):  # pylint: disable=arguments-differ
         """
         List view for learner records for a given enterprise.
         """
