@@ -28,7 +28,7 @@ class EnterpriseLearnerEnrollmentSerializer(serializers.ModelSerializer):
             'course_list_price', 'amount_learner_paid', 'course_key', 'courserun_key',
             'course_title', 'course_pacing_type', 'course_start_date', 'course_end_date',
             'course_duration_weeks', 'course_max_effort', 'course_min_effort',
-            'course_primary_program', 'course_primary_subject', 'has_passed',
+            'course_primary_program', 'primary_program_type', 'course_primary_subject', 'has_passed',
             'last_activity_date', 'progress_status', 'passed_date', 'current_grade',
             'letter_grade', 'enterprise_user_id', 'user_email', 'user_account_creation_date',
             'user_country_code', 'user_username', 'enterprise_name', 'enterprise_customer_uuid',
