@@ -126,6 +126,13 @@ class AuditUsersEnrollmentFilterBackend(filters.BaseFilterBackend, FiltersMixin)
                     'enterprise_user_id',
                     flat=True
                 )
+                audit_enrollments_enterprise_user_ids = list(audit_enrollments_enterprise_user_ids)
+                LOGGER.info(
+                    "[ELV_ANALYTICS_API_V1] Enterprise: [%s], AuditDataReporting: [%s], AuditEnrollments: [%s]",
+                    enterprise_id,
+                    enable_audit_data_reporting,
+                    len(audit_enrollments_enterprise_user_ids)
+                )
                 queryset = queryset.exclude(enterprise_user_id__in=audit_enrollments_enterprise_user_ids)
 
         return queryset
